# Software Instructions

These folders includes .c code for the digitizer m4i.4451 [1] and Fortran code that implements .c code as c-routines. 

The compilation of the codes can be done using the first line of each Fortran files. Everything is implemented under Cent-OS system. Compatibility to other Linux distributions or windows has not been investigated.

It is also possible to use other software platforms for the digitizer cards such as MATLAB and Python. The function names to control the cards are the same throughout different environments. Hence, mitigation to other software platforms should be relatively straightforward. For more information, please see the documentation and examples from the manufacturer’s website [1]. In addition, please follow the manufacturer’s website to install corresponding libraries because they differ by the OS. 

## Programming the ADC

The file **m4iset_extrig_rms.c** contains the functions for the ADC card setup and receiver operation. The routine uses 3 arguments:  
```c
/**
 * Set m4i receiver card
 *
 * @param *pvData    16-bit data pointer for the received data
 * @param *lMemsize  32-bit memory length for the received data
 * @param *posttr    32-bit post trigger pointer to adjust the time window of the ADC. Please see manufacturer’s documentation for more about post trigger. 
 * @Return void
*/
void m4iset_(int16 *pvData, int32 *lMemsize, int32 *posttr)
    {
    drv_handle hDrv;                    // Receiver device 
    char szErrorText[ERRORTEXTLEN];    //  Error buffer
    //Card specific parameters
    ...
    ...
    ...
    }
```
## Compilation and Usage
The other two scripts **rec_m4i_fifo_tdfilter.f** and **rec_m4i_tdfilter_rms.f** implement the c routine. They need to be compiled with a Fortran complier. The first line in these files can be taken as an example i.e. copy and paste it into the OS terminal using the working folder. For example: 

```console
gfortran -O2 rec_m4i_fifo_tdfilter.f m4iset_extrig_rms.c -mcmodel=medium /usr/lib64/libspcm_linux.so -o rec_m4i_tdfltr
```
In order to use them you need to provide the receiver frequency range and desired output folder as follows:
```console
rec_m4i_tdfltr 297000000. 297000000. > Recorded_signal.dat
``` 
The receiver has 10 seconds timeout, which can be adjusted by adjusting the integer in spcm driver function:
```c
spcm_dwSetParam_i32 (hDrv, SPC_TIMEOUT, 10000);
```
If receiver does not detect any trigger, it automatically starts recording. Consequently prints "trigger forced" at the first line of the received signal.

## References

[1] M4i.4451-x8 | Spectrum Instrumentation https://spectrum-instrumentation.com/de/m4i4451-x8
